Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r52966 - branches/release/tools/build/CMake
From: dgregor_at_[hidden]
Date: 2009-05-13 11:30:06


Author: dgregor
Date: 2009-05-13 11:30:04 EDT (Wed, 13 May 2009)
New Revision: 52966
URL: http://svn.boost.org/trac/boost/changeset/52966

Log:
Use the variable BOOST_REGRESSION_TESTS to enable Boost regression testing
Text files modified:
   branches/release/tools/build/CMake/BoostCore.cmake | 4 ++--
   branches/release/tools/build/CMake/BoostTesting.cmake | 11 ++++++-----
   2 files changed, 8 insertions(+), 7 deletions(-)

Modified: branches/release/tools/build/CMake/BoostCore.cmake
==============================================================================
--- branches/release/tools/build/CMake/BoostTesting.cmake (original)
+++ branches/release/tools/build/CMake/BoostTesting.cmake 2009-05-13 11:30:04 EDT (Wed, 13 May 2009)
@@ -37,10 +37,11 @@
 # want or need to perform regression testing on Boost. The Boost build
 # is significantly faster when we aren't also building regression
 # tests.
-option(BUILD_TESTING "Enable testing" OFF)
+option(BUILD_REGRESSION_TESTS "Enable regression testing" OFF)
 
-if (BUILD_TESTING)
+if (BUILD_REGRESSION_TESTS)
   enable_testing()
+ mark_as_advanced(BUILD_TESTING)
 
   option(TEST_INSTALLED_TREE "Enable testing of an already-installed tree" OFF)
 
@@ -50,7 +51,7 @@
   if (TEST_INSTALLED_TREE)
     include("${CMAKE_INSTALL_PREFIX}/lib/Boost${BOOST_VERSION}/boost-targets.cmake")
   endif (TEST_INSTALLED_TREE)
-endif (BUILD_TESTING)
+endif (BUILD_REGRESSION_TESTS)
 
 #-------------------------------------------------------------------------------
 # This macro adds additional include directories based on the dependencies of
@@ -203,9 +204,9 @@
   set(BOOST_TEST_TESTNAME "${PROJECT_NAME}-${testname}")
   #message("testname: ${BOOST_TEST_TESTNAME}")
   # If testing is turned off, this test is not okay
- if (NOT BUILD_TESTING)
+ if (NOT BUILD_REGRESSION_TESTS)
     set(BOOST_TEST_OKAY FALSE)
- endif(NOT BUILD_TESTING)
+ endif(NOT BUILD_REGRESSION_TESTS)
 
 endmacro(boost_test_parse_args)
 


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- branches/release/tools/build/CMake/BoostCore.cmake (original)
+++ branches/release/tools/build/CMake/BoostCore.cmake 2009-05-13 11:30:04 EDT (Wed, 13 May 2009)
@@ -56,7 +56,7 @@
 # therefore, will build and install the library binary.
 #
 # For libraries that have regression tests, and when testing is
# enabled globally by the BUILD_TESTING option, this macro also
 # defines the TEST_BOOST_LIBNAME option (defaults to ON). When ON, the
 # generated makefiles/project files will contain regression tests for
 # this library.
@@ -313,7 +313,7 @@
       endforeach(SUBDIR ${THIS_PROJECT_SRCDIRS})
     endif()
 
- if(BUILD_TESTING AND THIS_PROJECT_TESTDIRS)
+ if(BUILD_REGRESSION_TESTS AND THIS_PROJECT_TESTDIRS)
       # Testing is enabled globally and this project has some
       # tests. Check whether we should include these tests.
       if (BOOST_TEST_LIBRARIES)
@@ -56,7 +56,7 @@
 #
 # For libraries that have regression tests, and when testing is
-# enabled globally by the BUILD_TESTING option, this macro also
+# enabled globally by the BUILD_REGRESSION_TESTS option, this macro also
 # defines the TEST_BOOST_LIBNAME option (defaults to ON). When ON, the
 # generated makefiles/project files will contain regression tests for

Modified: branches/release/tools/build/CMake/BoostTesting.cmake
==============================================================================